/**************************************************************************

FILE NAME:      func.c

DESCRIPTION:    Various support functions for the 2-DOF bartending robot.

                To set the robot motor angles, assign values to the 
                following global variables:
                  gYaw   : legal values are specified in pwm.h
                  gPitch : legal values are specified in pwm.h
---------------------------------------------------------------------------

AUTHOR:         Leo Stocco

COPYRIGHT:      (C) COPYRIGHT The University of British Columbia, 2006
                All Rights Reserved.

***************************************************************************/

#include "util.h"           // Utility function definitions
#include "robot.h"          // Robot defines
#include "func.h"           // Support function definitions & prototypes


/***************************************************************************
Function:      proxSense
Description:   See func.h for full description.
****************************************************************************/

void proxSense(void) {

  // Initialize proxVal so that it wil enter the loop
  unsigned int proxVal = PROX_THRESH;

  // If the proximity sensor sees something, wait until it goes away
  while (proxVal >= PROX_THRESH)
    proxVal = GetADC(PROX);

} // proxSense()


/***************************************************************************
Function:      scanRobot
Description:   See func.h for full description.
****************************************************************************/

void scanRobot(void) {

  static int count1 = 0;
  static int count2 = 0;
  static int sign1  = 1;
  static int sign2  = 1;
  volatile int idx;

  // Waste some time
  for (idx=0; idx<WASTED_TIME; idx++);
 
  // Servo 1 - Yaw
  if (count1 == RANGE_Y)
    sign1 = -1;
  else if (count1 == 0)
    sign1 = 1;

  count1 += sign1;
  gYaw= MINVAL_Y + count1;

  // Servo 2 - Pitch
  if (count2 == (RANGE_P >> 1))  // Just scan half of the pitch range
    sign2 = -1;
  else if (count2 == 0)
    sign2 = 1;

  count2 += sign2;
  gPitch= MINVAL_P + count2;

} // scanRobot()
