/**************************************************************************

FILE NAME:      isr.c

DESCRIPTION:    Interrupt Service Routine
                For the 2-DOF robotic bargender, the ISR performs 
                pulse-width-modulation to actuate the servo-motors.

---------------------------------------------------------------------------

AUTHOR:         Leo Stocco

COPYRIGHT:      (C) COPYRIGHT The University of British Columbia, 2006
                All Rights Reserved.

***************************************************************************/

#include "robot.h"          // Defines for the robot
#include "util.h"           // Utility library function definitions


// Global variables used to set the motor angles
unsigned char  gYaw   = MAXVAL_Y;
unsigned char  gPitch = MINVAL_P;

/***************************************************************************
Function:      PulseWidthMod
Parameters:    none
Return Value:  none
Description:   Interrupt service routine for interrupt 1 which implements
               a dual pulse-width-modulator.
****************************************************************************/

void PulseWidthMod(void) interrupt 1 using 1 {

  static unsigned char  isrTimer1 = 0;  // timer for PWM #1
  static unsigned char  isrTimer2 = 0;  // timer for PWM #2

  // PulseWidthMod
  if (isrTimer1 == gYaw) {
    isrTimer1 = 0;
    SERVO_Y = !SERVO_Y;
  } // if
  else
    isrTimer1++;

  // PWM #2
  if (isrTimer2 == gPitch) {
    isrTimer2 = 0;
    SERVO_P = !SERVO_P;
  } // if
  else
    isrTimer2++;

} // PulseWidthMod
